#!/usr/bin/env Rscript




setwd( paste(this.path::initwd,'/../',sep='') )
source('src/masterset.r')




#--------[ Load Data Sets]--------#
masterset_load('data/lifespan/generic/health/fertility/female/fertility-female-pregnancy.json')
masterset_load('data/lifespan/generic/health/fertility/female/fertility-female-sterility.json')
masterset_load('data/lifespan/generic/dating/okcupid/okcupid-looks-preference-distance-female.json')
masterset_load('data/lifespan/generic/health/aging/facial-aging-trajectory-female.json')
masterset_load('data/lifespan/generic/health/aging/facial-aging-trajectory-cumulative-female.json')
masterset_load('data/lifespan/generic/health/hormones/estrogen-female.json')

masterset_load('data/lifespan/united-states/economics/income/individual/us-income-individual-mean-male.json')
masterset_load('data/lifespan/generic/health/fertility/male/fertility-male-sperm-totalmotility.json')
masterset_load('data/lifespan/generic/dating/okcupid/okcupid-looks-preference-distance-male.json')
masterset_load('data/lifespan/generic/health/aging/facial-aging-trajectory-male.json')
masterset_load('data/lifespan/generic/health/aging/facial-aging-trajectory-cumulative-male.json')
masterset_load('data/lifespan/generic/health/hormones/testosterone-male.json')




#--------[ Process Data ]--------#
masterset_new(
  new_key   = 'smv.female',
  new_name  = 'Female Sexual Market Value',
  new_units = 'smv',
  new_data  = masterset_average(data.frame(
    masterset$fertility.female.pregnancy,
    masterset_rev(masterset$fertility.female.sterility),
    masterset$estrogen.free.female,
    masterset_rev(masterset$okcupid.looks.distance.female),
    masterset_rev(masterset$aging.facial.trajectory.cumulative.female)
  ))
)

masterset_new(
  new_key   = 'smv.male',
  new_name  = 'Male Sexual Market Value',
  new_units = 'smv',
  new_data  = masterset_average(data.frame(
    masterset$us.income.individual.mean.male,
    masterset$fertility.male.sperm.totalmotility,
    masterset$testosterone.free.male,
    masterset_rev(masterset$ok.cupid.looks.distance.male),
    masterset_rev(masterset$aging.facial.trajectory.cumulative.male)
  ))
)




#--------[ Create Graph ]--------#
masterset_graph_init( g_plab = 'Sexual Marketplace Value' )

masterset_graph_line( g_yvar=masterset$fertility.female.pregnancy, g_alpha=0.2 )
masterset_graph_line( g_yvar=masterset$fertility.female.sterility, g_alpha=0.2, g_rev=TRUE)
masterset_graph_line( g_yvar=masterset$estrogen.free.female, g_alpha=0.2 )
masterset_graph_line( g_yvar=masterset$aging.facial.trajectory.female, g_alpha=0.2 )
masterset_graph_line( g_yvar=masterset$okcupid.looks.distance.female, g_alpha=0.2 )

masterset_graph_line( g_yvar=masterset$us.income.individual.mean.male, g_alpha=0.2 )
masterset_graph_line( g_yvar=masterset$fertility.male.sperm.totalmotility, g_alpha=0.2 )
masterset_graph_line( g_yvar=masterset$testosterone.free.male, g_alpha=0.2 )
masterset_graph_line( g_yvar=masterset$aging.facial.tragectory.male, g_alpha=0.2 )
masterset_graph_line( g_yvar=masterset$ok.cupid.looks.distance.male, g_alpha=0.2 )

masterset_graph_line( g_yvar=masterset$smv.female )
masterset_graph_line( g_yvar=masterset$smv.male )

masterset_graph_save('examples/lifespan-sexual-market-value.svg')
