#!/usr/bin/env Rscript



masterset_graph_init <- function(
    g_xvar  = NULL,      # X-Axis variable
    g_yvar  = NULL,      # Y-Axis variable

    g_plab  = NULL,      # Main plot title/label  (default set none)
    g_labs  = NULL,      # Plot-Point labels      (default set by masterset_scope)
    g_llab  = NULL,      # Legend title/lable     (default set by masterset_scope)
    g_col   = NULL,      # Plot-Colors            (default set by masterset_scope)
    g_size  = NULL,      # Plot-Point size        (default set by dataset size)
    g_cat   = NULL,      # Plot-Category circles  (default set none)
    g_src   = NULL,      # Show data source       (default set true)
    
    g_xlab  = NULL,      # X-Axis title/label     (default set by masterset_meta)
    g_xunit = NULL,      # X-Axis grid units      (default set by masterset_meta)
    g_xlog  = NULL,     # X-Axis rescale to logarithmic
    
    g_ylab  = NULL,      # Y-Axis title/label     (default set by masterset_meta)
    g_yunit = NULL,      # Y-Axis grid units      (default set by masterset_meta)
    g_ylog  = NULL,     # Y-Axis rescale to logarithmic
    
    g_norm  = NULL,      # Normalize data (only applies to timescale data)
    g_rev   = NULL,      # Invert Y-Axis data (only applise to timescale data)
    
    g_save  = NULL       # Save graph
) {
  
  
  
  #--------[ Global Config Variables ]--------#
  if(masterset_scope=='lifespan'){
    if(!is.null(g_norm)){ masterset_conf$g_norm <<- g_norm }else{ masterset_conf$g_norm <<- TRUE }
  }else{
    if(!is.null(g_norm)){ masterset_conf$g_norm <<- g_norm }else{ masterset_conf$g_norm <<- FALSE }
  }
  if(!is.null(g_xlog)){ masterset_conf$g_xlog <<- g_xlog }else{ masterset_conf$g_xlog <<- FALSE }
  if(!is.null(g_ylog)){ masterset_conf$g_ylog <<- g_ylog }else{ masterset_conf$g_ylog <<- FALSE }
  if(!is.null(g_src)) { masterset_conf$g_src  <<- g_src  }else{ masterset_conf$g_src  <<- TRUE  }
  
  
  
  #--------[ Create Graph ]--------#  
  masterset_graph <<- ggplot(
    data=masterset
  )
  
  
  
  #--------[ Common Theme Elements ]--------#
  masterset_graph <<- masterset_graph + theme(
    plot.margin         = unit(c(0.25, 0.25, 0.25, 0.25), 'inch'),
    panel.border        = element_rect(color='#000000', fill=NA),
    panel.background    = element_rect(fill='#cccccc'),
    
    plot.title          = element_text(size=18, hjust=0.5),
    plot.title.position = 'plot',
    axis.title.x        = element_text(size=13),
    axis.title.y        = element_text(size=13),
    plot.caption        = element_text(size=7),
  )
  
  
  
  #--------[ Draw Titles And Labels]--------#
  if( !is.null(g_plab) ){ masterset_graph <<- masterset_graph + ggtitle(g_plab) }
  if( !is.null(g_xlab) ){ masterset_graph <<- masterset_graph + xlab(g_xlab) }
  if( !is.null(g_ylab) ){ masterset_graph <<- masterset_graph + ylab(g_ylab) }
  
  
  
  #--------[ Legend Theme And Position ]--------#
  masterset_graph <<- masterset_graph + guides( fill = guide_legend(override.aes = list(size=8)) )
  
  if( masterset_scope=='lifespan'){
    masterset_graph <<- masterset_graph + theme( legend.position = c(0.98,0.95), legend.justification = c(1,1) )
  }else if( masterset_scope=='historical'){
    masterset_graph <<- masterset_graph + theme( legend.position = c(0.02,0.5), legend.justification = c(0,0.5) )
  }else{
    masterset_graph <<- masterset_graph + theme( legend.position = c(0.98,0.05), legend.justification = c(1,0) )
  }
  
  
}
