#!/usr/bin/env Rscript



masterset_graph_line <- function(
  g_xvar  = NULL,  # X-Axis variable
  g_yvar  = NULL,  # Y-Axis variable

  g_alpha  = 1.0,   # Line Alpha
  
  g_llab  = NULL,  # Legend title/lable     (default set by masterset_scope)
  
  g_rev  = FALSE   # Invert Y-Axis data (only applise to timescale data)
){
  
  
  
  #--------[ Global Variables ]--------#
  if( is.null(g_xvar) ){
    if( masterset_scope == 'historical' ){
      g_xvar <- masterset$year
      masterset_graph <<- masterset_graph + xlab('Year')
    }
    if( masterset_scope == 'lifespan' ){
      g_xvar <- masterset$age
      masterset_graph <<- masterset_graph + xlab('Age')
    }
  }
  
  
  
  #--------[ Set Labels ]--------#
  if( masterset_conf$g_norm ){ masterset_graph <<- masterset_graph + ylab('Normalised Variables') }
  else{ masterset_graph <<- masterset_graph + ylab('Raw Variables') }

  if( g_rev ){ tmp_lab <- paste(get_meta(g_yvar)$name,"(inverted)") }
  else{ tmp_lab <- get_meta(g_yvar)$name }
  
  if( length(unique(masterset_meta$id.cat)) > 1 ){
    masterset_graph <<- masterset_graph + scale_color_discrete( name = "Variables" )
    tmp_lab <- paste(get_meta(g_yvar)$id.cat, '|', tmp_lab  )
  }else{
    masterset_graph <<- masterset_graph + scale_color_discrete( name = masterset_meta$id.cat[1] )
  }
  
  
  
  #--------[ Process Data ]--------#
  g_yvar_temp <- g_yvar
  if( masterset_conf$g_norm ){ g_yvar_temp <- masterset_norm(g_yvar_temp) }
  if( g_rev  ){ g_yvar_temp <- masterset_rev(g_yvar_temp) }
  

  
  #--------[ Graph Points ]--------#
  masterset_graph <<- masterset_graph + geom_point(
    aes(
      x     = g_xvar,
      y     = g_yvar_temp,
      color = tmp_lab
    ),
    size    = 1,
    alpha   = g_alpha
  )
  
  
  
  #--------[ Graph Lines ]--------#
  masterset_graph <<- masterset_graph + geom_line(
    aes(
      x     = g_xvar,
      y     = na.approx(g_yvar_temp, na.rm=FALSE),
      color = tmp_lab
    ),
    alpha   = g_alpha
  )
  
  
  
  #--------[ Draw Graph]--------#
  print( masterset_graph )
  
  
  
}