#!/usr/bin/env Rscript



#--------[ Load Data Function ]--------#
masterset_load <- function(filename) {
  
  
  
  #--------[ Load File Data ]--------#
  fileData <- paste(readLines(filename), collapse=' ')
  tmpData <- as.data.frame(fromJSON(fileData)$data)

  colnames(tmpData) <- tmpData[1,]
  tmpData <- tmpData[-1,]
  
  
  
  #--------[ Process Data Bins ]--------#
  if( colnames(tmpData)[1]=='age.bin' || colnames(tmpData)[1]=='year.bin' ){
    
    if( colnames(tmpData)[1]=='age.bin'  ){ tmp_bin <- 'age.bin' }
    if( colnames(tmpData)[1]=='year.bin' ){ tmp_bin <- 'year.bin' }
    
    for( i in 1:length(tmpData[,tmp_bin]) ){
      if( grepl('-', tmpData[,tmp_bin][i], fixed=TRUE) ){
        tmp_row <- strsplit(tmpData[,tmp_bin][i], split='-')
        tmpData[,tmp_bin][i] <- (as.numeric(tmp_row[[1]][1]) + as.numeric(tmp_row[[1]][2]))/2
      }    
      if( grepl('+', tmpData[,tmp_bin][i], fixed=TRUE) ){
        tmp_row <- str_replace(tmpData[,tmp_bin][i], '\\+', '')
        tmpData[,tmp_bin][i] <- as.numeric(tmp_row)
      }
      if( grepl('>', tmpData[,tmp_bin][i], fixed=TRUE) ){
        tmp_row <- str_replace(tmpData[,tmp_bin][i], '>', '')
        tmpData[,tmp_bin][i] <- as.numeric(tmp_row)
      }
      if( grepl('<', tmpData[,tmp_bin][i], fixed=TRUE) ){
        tmp_row <- str_replace(tmpData[,tmp_bin][i], '<', '')
        tmpData[,tmp_bin][i] <- as.numeric(tmp_row)
      }
    }
    
    if( colnames(tmpData)[1]=='age.bin'  ){ colnames(tmpData)[1] <- 'age' }
    if( colnames(tmpData)[1]=='year.bin' ){ colnames(tmpData)[1] <- 'year' }
  }
  
  

  #--------[ Process Each Data Column ]--------#    
  for (i in colnames(tmpData)){
    if (suppressWarnings( !is.na(as.numeric( tmpData[[i]][1] )) )) {
      tmpData[[i]] <- as.numeric(tmpData[[i]])
    }
      
    #--------[ Compile Metadata ]--------#
    if (
      i != 'country.name' &&
      i != 'county.fips' &&
      i != 'year' &&
      i != 'age'
    ){
      tmpMeta <- fromJSON(fileData)$metadata
      masterset_meta <<- rbind(masterset_meta, data.frame(
        id          = i,
        id.cat      = tmpMeta$scope,
        name        = tmpMeta$name,
        description = tmpMeta$description,
        units       = tmpMeta$units,
        year        = tmpMeta$year,
        author      = tmpMeta$author[1],
        source      = tmpMeta$source[1]
      ))
    }
  }
    
    
  
  #--------[ Merge Current Global Data ]--------#
  if (grepl('global', filename, fixed=TRUE)) {
    message(paste('[MASTERSET] importing global data -> ',filename))
    masterset_scope <<- 'global'    
    #--------[ Check country.name Column and Merge ]--------#
    if ('country.name' %in% colnames(masterset)) {
      masterset <<- merge(
        masterset,
        tmpData,
        by.x = 'country.name'
      )
    }else{
      masterset <<- tmpData
    }
  }
  
  
  #--------[ Merge Historical Global Data ]--------#
  if (grepl('historical', filename, fixed=TRUE)) {
    message(paste('[MASTERSET] importing historical data -> ',filename))
    masterset_scope <<- 'historical'    
    #--------[ Check country.name Column and Merge ]--------#
    if ('year' %in% colnames(masterset)) {
      masterset <<- merge(
        masterset,
        tmpData,
        by.x = 'year',
        all  = TRUE
      )
    }else{
      masterset <<- tmpData
    }
  }
  
  
  #--------[ Merge Country/United-States Data ]--------#
  if (grepl('regional/united-states', filename, fixed=TRUE)) {
    message(paste('[MASTERSET] importing regional/united-states data -> ',filename))
    masterset_scope <<- 'regional/united-states'    
    #--------[ Check country.name Column and Merge ]--------#
    if ('us.county.fips' %in% colnames(masterset)) {
      masterset <<- merge(
        masterset,
        tmpData,
        by.x = 'us.county.fips'
      )
    }else{
      masterset <<- tmpData
    }
  }

  
  #--------[ Merge Lifespan Data ]--------#
  if (grepl('lifespan', filename, fixed=TRUE)) {
    message(paste('[MASTERSET] importing lifespan data -> ',filename))
    masterset_scope <<- 'lifespan'    
    #--------[ Check country.name Column and Merge ]--------#
    if ('age' %in% colnames(masterset)) {
      masterset <<- merge(
        masterset,
        tmpData,
        by.x = 'age',
        all  = TRUE
      )
    }else{
      masterset <<- tmpData
    }
  }
  

}
