#!/usr/bin/env Rscript



#--------[ Get Metadata for Dataset ]--------#
get_meta <- function(tmp_var) {
  for (col in colnames(masterset)){
    if ( identical(tmp_var, masterset[[col]]) ){
      return(masterset_meta[masterset_meta$id==col,])
    }
  }
}



#--------[ Normalise Data Values ]--------#
masterset_norm <- function(tmp_data) {
  return( (tmp_data - min(tmp_data, na.rm=TRUE)) / (max(tmp_data, na.rm=TRUE)-min(tmp_data, na.rm=TRUE)) )
}



#--------[ Reverse Data Values ]--------#
masterset_rev <- function(tmp_data) {
  return( max(tmp_data, na.rm=TRUE) - tmp_data )
}



#--------[ Interpolate NA Values ]--------#
masterset_est <- function(tmp_data) {
  
}



#--------[ Create New Dataset ]--------#
masterset_new <- function(
    new_data,
    new_key,
    new_name,
    new_units=''
){
  masterset[new_key] <<- new_data
  masterset_meta[nrow(masterset_meta)+1,] <<- c(
    id          = new_key,
    id.cat      = ifelse(length(unique(masterset_meta$id.cat))>1, 'Generated', masterset_meta$id.cat[1] ),
    name        = new_name,
    description = 'R Generated',
    units       = new_units,
    year        = format(Sys.Date(), "%Y"),
    author      = 'R-Script',
    source      = 'R-Script'
  )
}


#--------[ Averate Datasets ]--------#
masterset_average <- function( dataset ){
  
  for( i in 1:ncol(dataset) ){
    NonNAindex <- which( !is.na(dataset[i]) )
    
    dataset[1, i]             <- dataset[min(NonNAindex),i]
    dataset[nrow(dataset), i] <- dataset[max(NonNAindex),i]
    
    dataset[i] <- na.approx( dataset[i] )
    dataset[i] <- masterset_norm( dataset[i] )
  }  

  tmp_dataset <- rowMeans( dataset )
  return( tmp_dataset )
}

